#!/bin/sh

WORKLOADS_DIR="$(dirname $0)"
WORKLOADS="$(cd $WORKLOADS_DIR && ls *.nfsometer 2>&1 | sed 's/.nfsometer//g')"

usage()
{
	[ -n "$*" ] && echo $* >&2
	echo "usage: $0 <command> [args]" >&2

	echo "XXX" >&2
	exit 1
}

check_rundir() {
	if [ -z "$RUNDIR" -o ! -d "$RUNDIR" ] ; then
		usage "RUNDIR not defined"
	fi
}

check_testdir() {
	if [ -z "$TESTDIR" -o ! -d "$TESTDIR" ] ; then
		usage "TESTDIR not defined"
	fi
}

check_dirs() {
	check_rundir
	check_testdir
}

do_fetch()
{
	_ret=0

	W=$1.nfsometer
	source $WORKLOADS_DIR/$W

	cd $TESTDIR

	if [ -n "$URL" -a -n "$URL_OUT" ] ; then
		if [ ! -f "$URL_OUT" ]; then
			wget -O "$URL_OUT" "$URL"
			_ret=$?

			if [ $_ret -ne 0 ] ; then
				rm -f "$URL_OUT"
			fi
		fi
	fi

	return $_ret
}

do_check()
{
	W=$1.nfsometer
	source $WORKLOADS_DIR/$W

	cd $TESTDIR

	workload_check

	return $?
}

do_setup()
{
	W=$1.nfsometer
	source $WORKLOADS_DIR/$W

	cd $TESTDIR

	workload_setup

	return $?
}

get_command()
{
	W=$1.nfsometer
	source $WORKLOADS_DIR/$W

	echo $COMMAND
}

get_description()
{
	W=$1.nfsometer
	source $WORKLOADS_DIR/$W

	echo $DESCRIPTION
}

get_url()
{
	W=$1.nfsometer
	source $WORKLOADS_DIR/$W

	echo $URL
}

get_url_out()
{
	W=$1.nfsometer
	source $WORKLOADS_DIR/$W

	echo $URL_OUT
}

if [ $# -lt 1 ] ; then
	usage
fi

CMD="$1"

if [ "$CMD" = "list" ]; then
	echo $WORKLOADS | sort

elif [ "$CMD" = "check" ]; then
	check_testdir
	if [ $# -ne 2 ] ; then
		usage "check expects one argument <workload>"
	fi
	do_check $2

elif [ "$CMD" = "setup" ]; then
	check_dirs
	if [ $# -ne 2 ] ; then
		usage "setup expects one argument <workload>"
	fi
	do_setup $2

elif [ "$CMD" = "command" ]; then
	#check_dirs
	if [ $# -ne 2 ] ; then
		usage "command expects one argument <workload>"
	fi
	get_command $2

elif [ "$CMD" = "description" ]; then
	#check_dirs
	if [ $# -ne 2 ] ; then
		usage "description expects one argument <workload>"
	fi
	get_description $2

elif [ "$CMD" = "url" ]; then
	check_testdir
	if [ $# -ne 2 ] ; then
		usage "url expects one argument <workload>"
	fi
	get_url $2

elif [ "$CMD" = "url_out" ]; then
	check_testdir
	if [ $# -ne 2 ] ; then
		usage "url_out expects one argument <workload>"
	fi
	get_url_out $2

else
	usage "invalid command: $CMD"
fi

